/**
 * @since 1.0.0
 */
import { type IoTDataPlaneClient, type IoTDataPlaneClientConfig, type DeleteThingShadowCommandInput, type DeleteThingShadowCommandOutput, type GetRetainedMessageCommandInput, type GetRetainedMessageCommandOutput, type GetThingShadowCommandInput, type GetThingShadowCommandOutput, type ListNamedShadowsForThingCommandInput, type ListNamedShadowsForThingCommandOutput, type ListRetainedMessagesCommandInput, type ListRetainedMessagesCommandOutput, type PublishCommandInput, type PublishCommandOutput, type UpdateThingShadowCommandInput, type UpdateThingShadowCommandOutput } from "@aws-sdk/client-iot-data-plane";
import { Effect, Layer } from "effect";
import { ConflictError, InternalFailureError, InvalidRequestError, MethodNotAllowedError, RequestEntityTooLargeError, ResourceNotFoundError, ServiceUnavailableError, ThrottlingError, UnauthorizedError, UnsupportedDocumentEncodingError, SdkError } from "./Errors";
import { IoTDataPlaneClientInstance } from "./IoTDataPlaneClientInstance";
import { IoTDataPlaneClientInstanceConfig } from "./IoTDataPlaneClientInstanceConfig";
/**
 * @since 1.0.0
 */
export interface HttpHandlerOptions {
    /**
     * The maximum time in milliseconds that the connection phase of a request
     * may take before the connection attempt is abandoned.
     */
    requestTimeout?: number;
}
interface IoTDataPlaneService$ {
    readonly _: unique symbol;
    /**
     * @see {@link DeleteThingShadowCommand}
     */
    deleteThingShadow(args: DeleteThingShadowCommandInput, options?: HttpHandlerOptions): Effect.Effect<DeleteThingShadowCommandOutput, SdkError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | ResourceNotFoundError | ServiceUnavailableError | ThrottlingError | UnauthorizedError | UnsupportedDocumentEncodingError>;
    /**
     * @see {@link GetRetainedMessageCommand}
     */
    getRetainedMessage(args: GetRetainedMessageCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetRetainedMessageCommandOutput, SdkError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | ResourceNotFoundError | ServiceUnavailableError | ThrottlingError | UnauthorizedError>;
    /**
     * @see {@link GetThingShadowCommand}
     */
    getThingShadow(args: GetThingShadowCommandInput, options?: HttpHandlerOptions): Effect.Effect<GetThingShadowCommandOutput, SdkError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | ResourceNotFoundError | ServiceUnavailableError | ThrottlingError | UnauthorizedError | UnsupportedDocumentEncodingError>;
    /**
     * @see {@link ListNamedShadowsForThingCommand}
     */
    listNamedShadowsForThing(args: ListNamedShadowsForThingCommandInput, options?: HttpHandlerOptions): Effect.Effect<ListNamedShadowsForThingCommandOutput, SdkError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | ResourceNotFoundError | ServiceUnavailableError | ThrottlingError | UnauthorizedError>;
    /**
     * @see {@link ListRetainedMessagesCommand}
     */
    listRetainedMessages(args: ListRetainedMessagesCommandInput, options?: HttpHandlerOptions): Effect.Effect<ListRetainedMessagesCommandOutput, SdkError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | ServiceUnavailableError | ThrottlingError | UnauthorizedError>;
    /**
     * @see {@link PublishCommand}
     */
    publish(args: PublishCommandInput, options?: HttpHandlerOptions): Effect.Effect<PublishCommandOutput, SdkError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | ThrottlingError | UnauthorizedError>;
    /**
     * @see {@link UpdateThingShadowCommand}
     */
    updateThingShadow(args: UpdateThingShadowCommandInput, options?: HttpHandlerOptions): Effect.Effect<UpdateThingShadowCommandOutput, SdkError | ConflictError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | RequestEntityTooLargeError | ServiceUnavailableError | ThrottlingError | UnauthorizedError | UnsupportedDocumentEncodingError>;
}
/**
 * @since 1.0.0
 * @category constructors
 */
export declare const makeIoTDataPlaneService: Effect.Effect<IoTDataPlaneService$, never, IoTDataPlaneClientInstance>;
declare const IoTDataPlaneService_base: import("effect/Context").TagClass<IoTDataPlaneService, "@effect-aws/client-iot-data-plane/IoTDataPlaneService", IoTDataPlaneService$> & {
    readonly _: Effect.Effect<IoTDataPlaneService$["_"], never, IoTDataPlaneService>;
    deleteThingShadow: (args: DeleteThingShadowCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<DeleteThingShadowCommandOutput, InternalFailureError | InvalidRequestError | MethodNotAllowedError | ResourceNotFoundError | ServiceUnavailableError | ThrottlingError | UnauthorizedError | UnsupportedDocumentEncodingError | SdkError, IoTDataPlaneService>;
    getRetainedMessage: (args: GetRetainedMessageCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<GetRetainedMessageCommandOutput, InternalFailureError | InvalidRequestError | MethodNotAllowedError | ResourceNotFoundError | ServiceUnavailableError | ThrottlingError | UnauthorizedError | SdkError, IoTDataPlaneService>;
    getThingShadow: (args: GetThingShadowCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<GetThingShadowCommandOutput, InternalFailureError | InvalidRequestError | MethodNotAllowedError | ResourceNotFoundError | ServiceUnavailableError | ThrottlingError | UnauthorizedError | UnsupportedDocumentEncodingError | SdkError, IoTDataPlaneService>;
    listNamedShadowsForThing: (args: ListNamedShadowsForThingCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<ListNamedShadowsForThingCommandOutput, InternalFailureError | InvalidRequestError | MethodNotAllowedError | ResourceNotFoundError | ServiceUnavailableError | ThrottlingError | UnauthorizedError | SdkError, IoTDataPlaneService>;
    listRetainedMessages: (args: ListRetainedMessagesCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<ListRetainedMessagesCommandOutput, InternalFailureError | InvalidRequestError | MethodNotAllowedError | ServiceUnavailableError | ThrottlingError | UnauthorizedError | SdkError, IoTDataPlaneService>;
    publish: (args: PublishCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<PublishCommandOutput, InternalFailureError | InvalidRequestError | MethodNotAllowedError | ThrottlingError | UnauthorizedError | SdkError, IoTDataPlaneService>;
    updateThingShadow: (args: UpdateThingShadowCommandInput, options?: HttpHandlerOptions | undefined) => Effect.Effect<UpdateThingShadowCommandOutput, ConflictError | InternalFailureError | InvalidRequestError | MethodNotAllowedError | RequestEntityTooLargeError | ServiceUnavailableError | ThrottlingError | UnauthorizedError | UnsupportedDocumentEncodingError | SdkError, IoTDataPlaneService>;
} & {
    use: <X>(body: (_: IoTDataPlaneService$) => X) => X extends Effect.Effect<infer A, infer E, infer R> ? Effect.Effect<A, E, R | IoTDataPlaneService> : Effect.Effect<X, never, IoTDataPlaneService>;
};
/**
 * @since 1.0.0
 * @category models
 */
export declare class IoTDataPlaneService extends IoTDataPlaneService_base {
    static readonly defaultLayer: Layer.Layer<IoTDataPlaneService, never, never>;
    static readonly layer: (config: IoTDataPlaneClientConfig) => Layer.Layer<IoTDataPlaneService, never, never>;
    static readonly baseLayer: (evaluate: (defaultConfig: IoTDataPlaneClientConfig) => IoTDataPlaneClient) => Layer.Layer<IoTDataPlaneService, never, never>;
}
/**
 * @since 1.0.0
 * @category models
 * @alias IoTDataPlaneService
 */
export declare const IoTDataPlane: typeof IoTDataPlaneService;
/**
 * @since 1.0.0
 * @category layers
 * @deprecated use IoTDataPlane.baseLayer instead
 */
export declare const BaseIoTDataPlaneServiceLayer: Layer.Layer<IoTDataPlaneService, never, IoTDataPlaneClientInstance>;
/**
 * @since 1.0.0
 * @category layers
 * @deprecated use IoTDataPlane.layer instead
 */
export declare const IoTDataPlaneServiceLayer: Layer.Layer<IoTDataPlaneService, never, IoTDataPlaneClientInstanceConfig>;
/**
 * @since 1.0.0
 * @category layers
 * @deprecated use IoTDataPlane.defaultLayer instead
 */
export declare const DefaultIoTDataPlaneServiceLayer: Layer.Layer<IoTDataPlaneService, never, never>;
export {};
